@@ -18,4 +18,6 @@ struct _Theme {
 
 
 const gchar *theme_get_player (PlayerID who);
+const gchar *theme_get_player_win (PlayerID who);
+const gchar *theme_get_player_turn (PlayerID who);
 const gchar *theme_get_title (gint id);
